===============================
networking-cisco
===============================

Networking Cisco contains the Cisco vendor code for OpenStack Neutron

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/networking-cisco
* Source: http://git.openstack.org/cgit/openstack/networking-cisco
* Bugs: http://bugs.launchpad.net/networking-cisco

Features
--------

* TODO
